% bicmat.cls 26/09/2022
\typeout{************************************************************}
\typeout{*  Boletim de Iniciacao Cientifica em Matematica            }
\typeout{*                                                           }
\typeout{*           FORMATO LaTeX PARA O BICMat                     }
\typeout{*                                                           }
\typeout{*    Autor: THIAGO DE MELO (thiago.melo@unesp.br)           }
\typeout{*    Sugestoes e correcoes sao bem-vindas!                  }
\typeout{*    Ultima atualizacao: 26/09/2022 (Thiago de Melo)        }
\typeout{*                                                           }
\typeout{************************************************************}

\ProvidesClass{bicmat}[2022/09/26 v3 Classe Revista BICMat]
\NeedsTeXFormat{LaTeX2e}
\LoadClass[11pt,onecolumn,oneside,openany]{report}

\IfFileExists{lipsum.sty}{\RequirePackage{lipsum}}{\def\lipsum{lipsum}}
\RequirePackage{lmodern}
\RequirePackage{xcolor}
\RequirePackage{graphicx}
\RequirePackage[T1]{fontenc}
\RequirePackage{amsmath,amsfonts,amssymb,amsthm}
\RequirePackage{geometry}
\geometry{a4paper,bottom=1.5cm,includefoot,top=2cm,includehead,head=.8cm,left=2.75cm,right=2.75cm,headsep=.5cm}

\let\@afterindentfalse\@afterindenttrue\@afterindenttrue
\setcounter{tocdepth}{0}

\AtBeginDocument{%
  \pagenumbering{arabic}%
  \pagestyle{headings}%
  \baselineskip 1.25em
  \def\qedsymbol{\rule{.5em}{.5em}}
}

\AtEndDocument{%
	\pdfinfo{
		/Title (\bicmat\ Vol.\ \thevolume\ (\the\year))
		/Creator (\deptoname, Unesp Rio Claro)
		%	/Producer (pdfTeX 1.40.0)
		/Author (\string\124\string\150\string\151\string\141\string\147\string\157 \string\144\string\145 \string\115\string\145\string\154\string\157)
		/Subject (\bicmatname)
		/Keywords (\bicmat, \igce, Unesp Rio Claro)
	}
}

\newif\if@debug
\DeclareOption{debug}{\@debugtrue}
\ProcessOptions\relax

%%%% Comandos para DEBUG. Não alterar.
\if@debug
  \RequirePackage{showframe}
  \RequirePackage{lipsum}
  \setlength{\overfullrule}{5pt}
  \def\linhabase{\makebox[0pt][l]{\rule[0pt]{\textwidth}{.4pt}}}
  \AddToShipoutPictureFG{%
  \begin{picture}(0,0)%
  \setlength\unitlength{1cm}%
  \put(1,15){%
  \parbox[t]{2.1cm}{\raggedright\color{red}\footnotesize%
        DEBUG\\
        \if@twoside{twoside}\\\else{oneside}\\\fi
        \if@openright{openright}\\\else{openany}\\\fi
        pg.\ \thepage
  }}%
  \end{picture}%
  }
\else
  \newcommand{\linhabase}{\relax}
\fi


\def\cleardoublepage{%
  \clearpage 
  \if@twoside 
    \ifodd 
      \c@page 
    \else 
      \thispagestyle{empty}
      \hbox {}
      \newpage 
      \if@twocolumn 
        \hbox {} 
        \newpage 
      \fi
    \fi
  \fi
}

\newcommand{\data}[1]{\date{#1}}
\newcommand{\editorialname}{Editorial}
\newcommand{\deptoname}{Departamento de Matem\'{a}tica}
\newcommand{\igce}{IGCE}
\newcommand{\bicmatname}{Boletim de Inicia\c{c}\~{a}o Cient\'{\i}fica em Matem\'{a}tica}
\newcommand{\bicmat}{BICMat}
\newcommand{\issn}{\MakeUppercase{issn~1980--024x}}
\newcommand{\paginas}{\thepage--\pageref{\thepart-last}}

\colorlet{azul}{blue!70}

\newcounter{volume}
\setcounter{volume}{0}
\def\@volume{\Roman{volume}}
\def\volume#1{\setcounter{volume}{#1}}
\def\data#1{\gdef\@data{#1}}

\def\mes{\ifcase\month\or
  Janeiro\or Fevereiro\or Mar\c co\or Abril\or Maio\or Junho\or
  Julho\or Agosto\or Setembro\or Outubro\or Novembro\or Dezembro\fi
  \space
}

\renewcommand{\thefootnote}{\ifcase\value{footnote}
  \or \textdagger
  \or \textdagger\textdagger
  \else \arabic{footnote}\fi
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% defini\c{c}\~{a}o das macros para ambiente de teoremas
%
\newcommand{\axiomname}{Axioma}
\newcommand{\theoremname}{Teorema}
\newcommand{\corollaryname}{Corol\'{a}rio}
\newcommand{\lemmaname}{Lema}
\newcommand{\propositionname}{Proposi\c{c}\~{a}o}
\newcommand{\conjecturename}{Conjectura}
\newcommand{\definitionname}{Defini\c{c}\~{a}o}
\newcommand{\observationname}{Observa\c{c}\~{a}o}
\newcommand{\notename}{Nota}
\newcommand{\examplename}{Exemplo}
\newcommand{\questionname}{Quest\~{a}o}
\newcommand{\exercisename}{Exerc\'{\i}cio}
\newcommand{\myproofname}{Prova}
\newcommand{\propertyname}{Propriedade}
\newcommand{\aplicationname}{Aplica\c{c}\~ao}

\newtheoremstyle{emph}{1em}{1em}{\itshape}{0pt}{\fontfamily{bch}\fontshape{n}\fontseries{b}\selectfont}{.}{1.3ex}{}
\newtheoremstyle{normal}{1em}{1em}{\normalfont}{0pt}{\fontfamily{bch}\fontshape{n}\fontseries{b}\selectfont}{.}{1.3ex}{}

\theoremstyle{emph}
\newtheorem*{teorema*}{\normalsize\theoremname}
\newtheorem{teorema}{\normalsize\theoremname}[section]
\newtheorem{corolario}[teorema]{\normalsize\corollaryname}
\newtheorem{lema}[teorema]{\normalsize\lemmaname}
\newtheorem{proposicao}[teorema]{\normalsize\propositionname}

\theoremstyle{normal}
\newtheorem{axioma}[teorema]{\normalsize\axiomname}
\newtheorem{conjectura}[teorema]{\normalsize\conjecturename}
\newtheorem{definicao}[teorema]{\normalsize\definitionname}
\newtheorem{observacao}[teorema]{\normalsize\observationname}
\newtheorem{nota}[teorema]{\normalsize\notename}
\newtheorem{exemplo}[teorema]{\normalsize\examplename}
\newtheorem{questao}[teorema]{\normalsize\questionname}
\newtheorem{exercicio}[teorema]{\normalsize\exercisename}
\newtheorem{aplicacao}{\normalsize\aplicationname}

\newenvironment{prova}[1][\fontfamily{bch}\fontshape{n}\fontseries{b}\selectfont\normalsize\myproofname]{\par
  \pushQED{\qed}%
  \normalfont \topsep6\p@\@plus6\p@\relax
  \trivlist
  \item[\hskip\labelsep
        \fontfamily{bch}\fontshape{n}\fontseries{b}\selectfont\normalsize #1\@addpunct{:}]\ignorespaces
}{%
  \popQED\endtrivlist\@endpefalse
}

%% Redefine funções matemáticas em português
\def\sin{\mathop{\operator@font sen}\nolimits}
\def\arcsin{\mathop{\operator@font arcsen}\nolimits}
\def\sinh{\mathop{\operator@font senh}\nolimits}
\def\arcsinh{\mathop{\operator@font arcsenh}\nolimits}
\def\tan{\mathop{\operator@font tg}\nolimits}
\def\arctan{\mathop{\operator@font arctg}\nolimits}
\def\tanh{\mathop{\operator@font tgh}\nolimits}
\def\arctanh{\mathop{\operator@font arctgh}\nolimits}
\def\cot{\mathop{\operator@font cotg}\nolimits}
\def\arccot{\mathop{\operator@font arccotg}\nolimits}

% inicio do cabe\c{c}alho para t\'{\i}tulo extenso
%% check
%\if@twoside   % --------< twoside
%  \def\ps@hugeheadings{%
%      \def\@evenfoot{\begin{tabular}{@{\hspace{3pt}}l@{\hspace{3pt}}}\hline{\footnotesize\sc BICMat,\, Volume \@volume,\, \@data}\end{tabular}}
%      \def\@oddfoot{\hfill\begin{tabular}{@{\hspace{3pt}}r@{\hspace{3pt}}}\hline{\footnotesize\sc BICMat,\, Volume \@volume,\, \@data}\end{tabular}}
%      \def\@evenhead{\footnotesize\thepage\hfil\truncate{.9\textwidth}{\sc\leftmark}\hfil}%
%      \def\@oddhead{\footnotesize\hfil\truncate{.9\textwidth}{\sc\leftmark}\hfil\thepage}%
%      \let\@mkboth\markboth
%    \def\chaptermark##1{%  ---- marca do cap\'{\i}tulo (em uso)
%      \markboth {\sc{%  --- tipo de fonte usada na marca
%        \ifnum \c@secnumdepth >\m@ne
%        \fi
%        ##1}}{}}%
%    \def\sectionmark##1{%   -------- marca da se\c{c}\~{a}o (n\~{a}o uso)
%      \markright {\bfseries\sc {%
%        \ifnum \c@secnumdepth >\z@
%        \fi
%        ##1}}
%        } }
%\else  % ------< oneside
%\def\ps@hugeheadings{
%      \def\@evenfoot{\begin{tabular}{@{\hspace{3pt}}l}\hline{\footnotesize\sc BICMat,\, Volume \@volume,\, \@data}\end{tabular}}
%      \def\@oddfoot{\hfill\begin{tabular}{r@{\hspace{3pt}}}\hline{\footnotesize\sc BICMat,\, Volume \@volume,\, \@data}\end{tabular}}
%      \def\@evenhead{\footnotesize\hfil\truncate{.85\textwidth}{\sc\leftmark}\hfil\thepage}%
%      \def\@oddhead{\footnotesize\hfil\truncate{.85\textwidth}{\sc\leftmark}\hfil\thepage}%
%      \let\@mkboth\markboth
%    \def\chaptermark##1{%
%      \markboth{%
%        \ifnum \c@secnumdepth >\m@ne
%           % \sc\@chapapp\ \@Roman\thechapter \normalfont \space --\ %n\~{a}o descomentar
%        \fi
%        ##1}{}}%
%    \def\sectionmark##1{%
%      \markright {\normalfont %
%        \ifnum \c@secnumdepth >\z@
%        %  \thesection.  %
%        \fi
%        ##1}}}
%\fi 
%% fim do cabe\c{c}alho para t\'{\i}tulo extenso

\def\ps@headings{%
  \let\@evenfoot\@oddfoot
  \let\@evenhead\@oddhead
  \def\@oddfoot{%
    \hfill%
      \begin{tabular}{@{}l@{}}%
        \hline{\scshape\footnotesize\bicmat, Volume~\@volume, \@data}
      \end{tabular}%
  }
  \def\@oddhead{%
    \scshape\footnotesize\hfil\@titulo\hfil\llap{\thepage}%
  }
}

\def\ps@firstpage{%
    \let\@evenfoot\@oddfoot
    \let\@evenhead\@oddhead
    \def\@oddfoot{%
      \hfil\footnotesize\thepage\hfil
      \llap{\parbox[t]{3.4cm}{\vskip -1.6em\rule{\linewidth}{1pt}\\\hspace*{\fill}\tiny\deptoname\\\hspace*{\fill}\igce\ \textbf{\textperiodcentered} Unesp Rio Claro}}%
    }
  \def\@oddhead{%
    \noindent%
    \parbox[b]{5.5cm}{%
      \noindent\rule{\linewidth}{1pt}\\
      \tiny\MakeUppercase{\bicmatname} \textbf{\textperiodcentered}\ \bicmat\\
      Vol.\ \arabic{volume} (\the\year) \paginas%
    }\hfill
  }
}

\def\ps@issn{%
  \let\@oddfoot\@empty
  \let\@evenfoot\@empty
  \def\@evenhead{\hfil\footnotesize\issn}
  \def\@oddhead{\hfil\footnotesize\issn}
}

\newcommand*{\@titulo}{}

\newcommand{\titulo}[1]{\part{#1}}
\renewcommand\part{%
  \secdef\@part\@spart
}

\def\@part[#1]#2{%
  \if@openright\cleardoublepage\else\clearpage\fi
  \refstepcounter{part}%
  \setcounter{teorema}{0}
  \thispagestyle{firstpage}
  \pagestyle{headings}
  \addcontentsline{toc}{part}{#1\hfill}
  \renewcommand*{\@titulo}{#1}
  \vspace*{2em}
  {\centering
   \interlinepenalty \@M
   \normalfont
   \ifnum \c@secnumdepth >-2\relax
%     \fontfamily{fve}\selectfont
    \Large\bfseries #2
    \par
    \vskip 15\p@
   \fi
  }%
}

\newcommand{\autores}[3][Autor 1 \and Autor 2]{%
\chapter[#1]{#2}{#3}%
}
\renewcommand\chapter{%
  %\if@openright\cleardoublepage\else\clearpage\fi
  \thispagestyle{firstpage}% changed
  \global\@topnum\z@
  \@afterindentfalse
  \secdef\@chapter\@schapter
}

\def\@chapter[#1]#2#3{%
  \ifnum \c@secnumdepth >\m@ne
%    \renewcommand*{\autor}{#1}
    \refstepcounter{chapter}%
    \addcontentsline{toc}{chapter}{\protect\numberline{}#1}
  \else
    \addcontentsline{toc}{chapter}{#1}%
  \fi
  \if@twocolumn
    \@topnewpage[\@makeauthorhead{#2}]%
  \else
    \@makeauthorhead{#2}
    %% test if #3 is empty
    \if\relax\detokenize{#3}\relax
      \vskip 25\p@ \par%
    \else
      \@makeprofhead{#3}%
    \fi
    \@afterheading
  \fi
}

\def\@makeauthorhead#1{%
  {\parindent \z@ \raggedright \normalfont
    \interlinepenalty\@M
    \centering
    \large #1 \par
  }%
}

\def\@makeprofhead#1{
  {\parindent \z@ \raggedright \normalfont
    \interlinepenalty\@M
    \centering
    {\small Orientador(a): #1} \par
    \vskip 25\p@ \par
  }%
}

\renewcommand{\thesection}{\@arabic\c@section}
\renewcommand\section{\@startsection {section}{1}{\z@}%
		     {-3.5ex \@plus -1ex \@minus -.2ex}%
		     {2.3ex \@plus.2ex}%
		     {\fontfamily{ppl}\fontshape{n}\fontseries{m}\fontsize{12.4}{14}\selectfont}} %--- muda a fonte do \section
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
		       {-3.25ex\@plus -1ex \@minus -.2ex}%
		       {1.5ex \@plus .2ex}%
		       {\fontfamily{ppl}\fontshape{n}\fontseries{m}\fontsize{11}{14}\selectfont}} %--- muda a fonte do \section
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
		       {-3.25ex\@plus -1ex \@minus -.2ex}%
		       {1.5ex \@plus .2ex}%
		       {\fontfamily{ppl}\selectfont\normalsize\itshape}}
\renewcommand\paragraph{\@startsection{paragraph}{4}{\z@}%
		      {3.25ex \@plus1ex \@minus.2ex}%
		      {-1em}%
		      {\normalfont\normalsize\bfseries}}
\renewcommand\subparagraph{\@startsection{subparagraph}{5}{\parindent}%
		         {3.25ex \@plus1ex \@minus .2ex}%
		         {-1em}%
		        {\normalfont\normalsize\bfseries}}

\def\resumoname{\fontfamily{ppl}\fontshape{n}\fontseries{b}\selectfont Resumo} 
\def\palavraschavename{\fontfamily{ppl}\fontshape{n}\fontseries{b}\selectfont Palavras-chave}
\def\absname{\fontfamily{ppl}\fontshape{it}\fontseries{m}\selectfont Abstract} 
\def\keyname{\fontfamily{ppl}\fontshape{it}\fontseries{m}\selectfont  Keywords} 
\def\agradname{\fontfamily{ppl}\fontshape{n}\fontseries{b}\selectfont  Agradecimentos}

\newenvironment{resumo}
	{\footnotesize\begin{list}{\resumoname:}{
	\setlength\labelsep{3pt}
	\setlength\itemindent{3pt}
	\setlength\leftmargin{2cm}
	\setlength\rightmargin{2cm}
	\setlength\labelwidth{0pt}
	\setlength\listparindent{\parindent}
	\setlength\topsep{0em}
	}}
	{\end{list}}

\newenvironment{palavraschave}
	{\footnotesize\begin{list}{\palavraschavename:}{
	\setlength\labelsep{3pt}
	\setlength\itemindent{3pt}
	\setlength\leftmargin{2cm}
	\setlength\rightmargin{2cm}
	\setlength\labelwidth{0pt}
	\setlength\listparindent{\parindent}
	\setlength\topsep{.25em}
	}}
	{\par\noindent\hfil\rule{.5\linewidth}{.7pt}\hfil\end{list}}

\renewenvironment{abstract}
	{\footnotesize\itshape\begin{list}{\absname:}{
	\setlength\labelsep{3pt}
	\setlength\itemindent{3pt}
	\setlength\leftmargin{2cm}
	\setlength\rightmargin{2cm}
	\setlength\labelwidth{0pt}
	\setlength\listparindent{\parindent}
	\setlength\topsep{.25em}
	}}
	{\end{list}}

\newenvironment{keywords}
  {\footnotesize\itshape\begin{list}{\keyname:}{
	\setlength\labelsep{3pt}
	\setlength\itemindent{3pt}
	\setlength\leftmargin{2cm}
	\setlength\rightmargin{2cm}
	\setlength\labelwidth{0pt}
	\setlength\listparindent{\parindent}
	\setlength\topsep{.25em}
	}}
	{\par\noindent\hfil\rule{.5\linewidth}{.7pt}\hfil\par\vskip 2\baselineskip plus 0pt minus 0pt\end{list}}

\newenvironment{agradecimentos}
	{\medskip
	\begin{list}{\agradname:}{
	\setlength\labelsep{3pt}
	\setlength\itemindent{3pt}
	\setlength\leftmargin{0cm}
%	\setlength\rightmargin{3cm}
	\setlength\labelwidth{0pt}
	\setlength\listparindent{\parindent}
	\setlength\topsep{0em}
	}}
	{\end{list}}

%% ------------- in\'{\i}cio da capa colorida
\newenvironment{capa}{%
  \thispagestyle{issn}
  \fontfamily{ppl}\fontshape{sc}\selectfont
  \vspace*{1em}

  \begin{center}%
  \noindent \rule{\textwidth}{2pt} \vskip -\baselineskip \vskip 3pt %
  \noindent \rule{\textwidth}{1pt} \vskip  \baselineskip %
  \huge{\color{azul}{\bicmatname\ {\fontshape{n}\selectfont\textperiodcentered}\ \bicmat}} %
  \noindent \rule{\textwidth}{1pt} \vskip -\baselineskip \vskip 4pt %
  \noindent \rule{\textwidth}{2pt} %
  \setlength\fboxsep{0pt}%
  \vfill
  \includegraphics[width=90mm,clip]{bicmat_logo_rgb}
  \vfill
  \large{\color{azul}Volume~\@volume \vskip.2em \@data \vskip .2em \deptoname \vskip .2em \igce\ {\fontshape{n}\selectfont\textperiodcentered}\ Rio Claro}\par
  \noindent \rule{.5\textwidth}{.7pt} \vskip .5em %
  \includegraphics[width=3cm]{logo_unesp_assinatura} % 
  \@endparpenalty\@M
  \end{center}
  }%
  {\normalfont\par\vfil\null}

%% ------------- in\'{\i}cio da capa gray
%% obsoleto
\newenvironment{capagray}{
      \fontfamily{ppl}\fontshape{sc}\selectfont
      %\titlepage
      %\vspace*{1em}
      \@beginparpenalty\@lowpenalty
	\begin{center}  %
	\thispagestyle{issn}
	\noindent \rule{\textwidth}{1pt} \vskip -1.5em %
	\noindent \rule{\textwidth}{2pt} \vskip 1em %
	\huge{\color{black}{\bicmatname--\bicmat}} %
	\noindent \rule{\textwidth}{1pt} \vskip -1em %
	\noindent \rule{\textwidth}{2pt} %
	\vskip 4em
	\includegraphics[width=80mm,clip]{bicmat_logo_gray}
	\vfill
	\large {\color{black}Volume \@volume \vskip.2em \@data \vskip .2em \deptoname \vskip .2em \large\igce--Rio Claro}\par
	\noindent \rule{.5\textwidth}{.7pt} \vskip .5em %
	\includegraphics[width=2cm]{logo_unesp_traco} %
      \@endparpenalty\@M
      \end{center}
      }%
  {\vfil\newpage}

\newenvironment{contracapa}{% 
    \clearpage
    \fontfamily{ppl}\selectfont
    \null %\vskip -6em
    \@beginparpenalty\@lowpenalty
    \begin{center}%
    \thispagestyle{issn}
    \parbox[t]{.7\linewidth}{%
      \centering\Large{\scshape \bicmatname\ {\fontshape{n}\selectfont\textperiodcentered}\ \bicmat}%
    }%
    \vskip 2em
    \@endparpenalty\@M
    \end{center}
    \itshape\bfseries\baselineskip=1.5em
  }%
  {\normalfont\par\vfil\null}

\newenvironment{editorial}{%
      \clearpage
      \fontfamily{ppl}\selectfont
      \null %\vskip -6em
      \@beginparpenalty\@lowpenalty
      \begin{center}%
      \thispagestyle{empty}
      \parbox[t]{.7\linewidth}{%
      	\centering\Large{\scshape \editorialname}%
      }%
      \vskip 2em
      \@endparpenalty\@M
      \end{center}\par
      \normalfont\baselineskip=1.5em
  }%
  {\normalfont\par\vfil\null}

\newenvironment{orientacao}{%
      \cleardoublepage
      \fontfamily{ppl}\selectfont
      \null %\vskip -6em
      \@beginparpenalty\@lowpenalty
      \begin{center}%
      \thispagestyle{issn}
      \parbox[t]{.7\linewidth}{%
        \centering\Large{\scshape \bicmatname\ {\fontshape{n}\selectfont\textperiodcentered}\ \bicmat}%
      }%
      \vskip 2em
      \@endparpenalty\@M
      \end{center}\par
      \noindent{\itshape\bfseries Orienta\c{c}\~{a}o aos autores}
      \normalfont\baselineskip=1.5em
  }%
  {\normalfont\par\vfil\null}

\def\@makeschapterhead#1{%
  \vspace*{50\p@}%
  {\parindent \z@ \raggedright
    \normalfont
    \interlinepenalty\@M
    \fontfamily{ppl}\fontshape{sc}\fontseries{b}\selectfont\LARGE  #1\par\nobreak
    \vskip 40\p@
  }}

\renewcommand\tableofcontents{%
  \chapter*{\contentsname}
  \@mkboth{\scshape\contentsname}{\scshape\contentsname}
  \thispagestyle{plain}
  \pagestyle{plain}%
  \@starttoc{toc}%
%  \if@restonecol\twocolumn\fi
}

\renewcommand*\l@part[2]{%
  \ifnum \c@tocdepth >-2\relax
    \addpenalty{-\@highpenalty}%
    \addvspace{2.3em \@plus\p@}%
    \setlength\@tempdima{3em}%
    \begingroup
      \parindent \z@ \rightskip \@pnumwidth
      \parfillskip -\@pnumwidth
      {\leavevmode
       \fontfamily{ppl}\fontseries{b}\fontshape{it}\selectfont\normalsize #1 \hfil \par}%\hfil \hb@xt@\@pnumwidth{\hss #2}}\par #1=Nome do autor
%       \nobreak
         \global\@nobreaktrue
         \everypar{\global\@nobreakfalse\everypar{}}%
    \endgroup
  \fi
}

\renewcommand*\l@chapter[2]{%
  \ifnum \c@tocdepth >\m@ne
    \addpenalty{-\@highpenalty}%
    \vskip .5em \@plus\p@
    \setlength\@tempdima{\parindent}%
    \begingroup
      \parindent \z@ \rightskip \@pnumwidth
      \parfillskip -\@pnumwidth
      \leavevmode
      \fontfamily{ppl}\fontseries{m}\fontshape{n}\selectfont
      \normalsize
      \advance\leftskip\@tempdima
      \hskip -\leftskip
      #1 \dotfill \nobreak\hb@xt@\@pnumwidth{\hss #2}\par
      \penalty\@highpenalty
    \endgroup
  \fi
}

\renewenvironment{thebibliography}[1]{%
  \section*{\bibname}%
  %\@mkboth{}{}%
  \list{\@biblabel{\@arabic\c@enumiv}}%
       {\settowidth\labelwidth{\@biblabel{#1}}%
        \leftmargin\labelwidth
        \advance\leftmargin\labelsep
        \@openbib@code
        \usecounter{enumiv}%
        \let\p@enumiv\@empty
        \renewcommand\theenumiv{\@arabic\c@enumiv}}%
  \sloppy
  \clubpenalty4000
  \@clubpenalty \clubpenalty
  \widowpenalty4000%
  \sfcode`\.\@m}
  {\def\@noitemerr
   {\@latex@warning{Ambiente `thebibliography' vazio}}%
  \endlist
  \label{\thepart-last}
}

\def\and{\space e \space}

\@addtoreset{equation}{section}
\renewcommand\theequation
  {\ifnum \c@section>\z@ \thesection.\fi\@arabic\c@equation}

\endinput